@@ -1,15 +1,31 @@
+`packageCheck` <-
+function(x,lib.loc=NULL){
+	if(!is.character(x))stop("x must be character")
+	if(length(x)!=1)stop("x must be atomic")
+	success <- library(x,character.only=TRUE,lib.loc=lib.loc,logical.return=TRUE)
+	if(!success){
+		return(0)
+	}
+	testResult <- try(suppressWarnings(example(x,local=TRUE)))
+	if(inherits(testResult,"try-error")){
+		return(0)
+	}
+	return(packageDescription(x,lib.loc=lib.loc,fields="Version"))
+}
 `accept` <-
 function(
 	contingencies=c(
 		"akima",
 		"boot",
 		"coda",
+		"chron",
 		"foreign",
 		"fork",
 		"lattice",
 		"locfit",
 		"MASS",
 		"nlme",
+		"plyr",
 		"R2WinBUGS",
 		"reshape",
 		"SASxport",
@@ -25,7 +41,7 @@ function(
 			installed <- installed.packages(lib.loc=.Library)[,1]
 			missing <- setdiff(contingencies,installed)
 			if(length(missing))try(
-				install.packages(missing,lib=.Library)
+				install.packages(missing,lib=.Library,type='source')
 			)
 		}
 		check <- sapply(contingencies,packageCheck,lib.loc=.Library)
@@ -52,4 +68,14 @@ function(
 	saveXML(doc,filepath)
 	invisible(check)
 }
+`acceptance` <-
+function(){
+	library(XML)
+	filepath <- file.path(.Library,"accept.xml")
+	as.XMLNode <- function(x,...)UseMethod("as.XMLNode")
+	as.XMLNode.XMLDocument <- function(x,...)xmlTreeParse(x,...)$doc$children[[1]]
+	as.XMLNode.character <- function(x,...)xmlTreeParse(x,...)$doc$children[[1]]
+	if(file.exists(filepath))return(as.XMLNode.XMLDocument(filepath,asText=FALSE))
+	return(NULL)
+}
 
